@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: session.h,v 1.24 2007/08/17 17:12:48 evertonm Exp $ */
+/* $Id: session.h,v 1.25 2007/10/18 21:51:44 evertonm Exp $ */
 
 #ifndef NEPIM_SESSION_H
 #define NEPIM_SESSION_H
@@ -37,6 +37,15 @@ typedef enum { SESSION_PIPE, SESSION_SLOT } nepim_session_type;
 
 typedef struct nepim_session_t nepim_session_t;
 
+typedef struct {
+  float kbps_in;
+  float kbps_out;
+  float pps_in;
+  float pps_out;
+  float pkt_loss;
+  float pkt_ooo;
+} nepim_mark_t;
+
 struct nepim_session_t {
 
   nepim_session_type type;
@@ -93,6 +102,10 @@ struct nepim_session_t {
   long long byte_interval_sent;
   long long byte_interval_recv;
 
+  nepim_mark_t min;
+  nepim_mark_t max;
+  int report_partial_min_max;
+
   struct timeval tv_duration;
   struct timeval tv_interval;
   struct timeval tv_start;
