@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: sock.c,v 1.55 2008/08/22 02:01:19 evertonm Exp $ */
+/* $Id: sock.c,v 1.57 2008/11/26 15:46:14 evertonm Exp $ */
 
 #include <assert.h>
 #include <netdb.h>
@@ -175,6 +175,7 @@ int nepim_sock_addrlen(const struct sockaddr *addr)
     assert(0);
   }
   assert(0);
+  return -1;
 }
 
 void nepim_sock_dump_addr(char *buf, int buf_size,
@@ -457,8 +458,8 @@ static int create_socket(FILE *err, int domain, int type, int protocol,
 static int iface_solve_index(const char *ifname)
 {
   struct if_nameindex *ini;
-  struct if_nameindex *i;
   int ifindex = -1;
+  int i;
 
   assert(ifname);
 
@@ -475,18 +476,17 @@ static int iface_solve_index(const char *ifname)
     return -1;
   }
 
-  for (i = ini; i->if_index > 0; ++i) {
+  for (i = 0; ini[i].if_index; ++i) {
     if (nepim_global.verbose_stderr) {
       fprintf(nepim_global.verbose_stderr,
-	      "%s: %s: interface=%s matching against local ifname=%s\n",
+	      "%s: %s: interface=%s matching against local ifname=%s ifindex=%d\n",
 	      __FILE__, __PRETTY_FUNCTION__,
-	      ifname, i->if_name);
+	      ifname, ini[i].if_name, ini[i].if_index);
     }
-    if (!strcmp(i->if_name, ifname)) {
-      ifindex = i->if_index;
+    if (!strcmp(ini[i].if_name, ifname)) {
+      ifindex = ini[i].if_index;
       break;
     }
-    ++i;
   }
 
   if_freenameindex(ini);
